@@ -11,6 +11,7 @@ from torch.utils.tensorboard import SummaryWriter
 def fun_control_init(
     _L_in=None,
     _L_out=None,
+    _torchmetric=None,
     PREFIX=None,
     TENSORBOARD_CLEAN=False,
     SUMMARY_WRITER=True,
@@ -37,6 +38,7 @@ def fun_control_init(
     noise=False,
     n_points=1,
     n_samples=None,
+    n_total=None,
     num_workers=0,
     ocba_delta=0,
     oml_grace_period=None,
@@ -68,6 +70,10 @@ def fun_control_init(
             The number of input features.
         _L_out (int):
             The number of output features.
+        _torchmetric (str):
+            The metric to be used by the Lighting Trainer.
+            For example "mean_squared_error",
+            see https://lightning.ai/docs/torchmetrics/stable/regression/mean_squared_error.html
         accelerator (str):
             The accelerator to be used by the Lighting Trainer.
             It can be either "auto", "dp", "ddp", "ddp2", "ddp_spawn", "ddp_cpu", "gpu", "tpu".
@@ -129,6 +135,8 @@ def fun_control_init(
             The number of infill points to be generated by the surrogate in each iteration.
         n_samples (int):
             The number of samples in the dataset. Default is None.
+        n_total (int):
+            The total number of samples in the dataset. Default is None.
         num_workers (int):
             The number of workers to use for the data loading. Default is 0.
         ocba_delta (int):
@@ -291,6 +299,7 @@ def fun_control_init(
         "TENSORBOARD_PATH": TENSORBOARD_PATH,
         "_L_in": _L_in,
         "_L_out": _L_out,
+        "_torchmetric": _torchmetric,
         "accelerator": accelerator,
         "converters": converters,
         "core_model": core_model,
@@ -322,6 +331,7 @@ def fun_control_init(
         "noise": noise,
         "n_points": n_points,
         "n_samples": n_samples,
+        "n_total": n_total,
         "num_workers": num_workers,
         "ocba_delta": ocba_delta,
         "oml_grace_period": oml_grace_period,
